# eric7.MicroPython.Devices.CircuitPythonUpdater.ShowInstalledDialog

Module implementing a dialog to show the modules installed on the connected device.

### Global Attributes

None

### Classes

ShowInstalledDialog | Class implementing a dialog to show the modules installed on the connected device.

### Functions

None

## ShowInstalledDialog

Class implementing a dialog to show the modules installed on the connected device.

### Derived from

QDialog, Ui_ShowInstalledDialog

### Class Attributes

None

### Class Methods

None

### Methods

ShowInstalledDialog | Constructor

### Static Methods

None

#### ShowInstalledDialog (Constructor)

ShowInstalledDialog(devicePath, parent=None)

Constructor

devicePath (str)
  path to the connected board
parent (QWidget (optional))
  reference to the parent widget (defaults to None)

Up